---
title: How to create a merge request
summary: Explains a common method to create a merge request.
authors:
    - Maurice Zimmnau
date: 2024-09-25
---

# How to create a merge request (MR)

You have already implemented an improvement to the current code base or intend to? Awesome 😎
Here are some instructions, on how to to that:

- First, make sure you have read the basics of how to contribute
- Read the following instructions:

There are several ways to create a merge request within GitLab, which are explained in detail in the [official GitLab docs](https://docs.gitlab.com/ee/user/project/merge_requests/creating_merge_requests.html).

However, we will highlight the workflow, we prefer - but feel free to make your own choice.

## Preferred merge request workflow
This is the first and preferred way to make a merge request, as it is similar to our previous UNICADO workflow.

Let's assume you have your own (local) feature branch, where you are developing a new feature. And let's further assume, you have forked this branch from the current main or develop branch. If not, you can do it now:

``` { .sh .copy }
git checkout develop
git pull origin develop
git checkout -b <new-branch-name>
```

*(Of course you can also perform the git operations via your tool of choice, e.g. VSCode)*

If you are working on this branch locally, and it is not shared with remote ☁️, then you have to push it ⏫ to remote, first in order to create a merge request. You can do that as simple as:

``` { .sh .copy }
git push origin <new-branch-name>
```
!!! note
    Please be aware that your branch name **must** follow this naming convention: `feature/some-feature`, `bugfix/some-bugfix` or `documentation/some_documentation`. Otherwise you will not be able to push it.

On the gitlab page of the repository in the left sidebar select **Code > Merge request** and select **New merge request**

- For **Source branch** select your branch `<new-branch-name>`
- For **Target branch** select in this case `develop`
- Select **Compare branches and continue**
- Fill out the description (check out the [commit rules](#commitrules) beforehand!)
- Enter a **Reviewer**
- Add labels
- **Create merge request**

!!! note
    Choose to delete the remote branch after merge, to keep remote clean

!!! note
    Choose squash as merge strategy, to keep the git history streamlined


Then you have to wait for the **Merge request pipeline** to pass ✅ (and hopefully not fail🤞) and for the **reviewer** to approve 👍 the request. In case you need to commit adaptions, check the [commit rules](#commitrules) again!

Afterwards on the page of the merge request, you can click on **merge**. Then your feature branch will be automatically merged into the remote branch of `develop` (in this example).

!!! note
    As a reviewer, **don't close** the merge request. It will be closed automatically, when the merge is completed.

## Commit rules and messages {#commitrules}

- Commit messages should be clear and concise.
- Use **English** language.
- Use the `#` to close and refer to issues.
- Please use **present tense** to express what the commit does.
- **Don't** commit code which you know is not working.
