---
title: Building the Release Package
summary: How to build C++ Installer packages of UNICADO.
authors:
    - Sebastian Oberschwendtner
date: 2024-05-29
---
When all module executables are built and tested, you can create an installer package for the **UNICADO** project.
CMake offers a convenient way to execute predefined workflow steps to build everything you need for the installer package and the installer itself.
The **UNICADO** project has a workflow defined for creating a **Release** package for *Windows* and *Linux*.

:fontawesome-solid-arrow-right: You can read more about the [workflow :octicons-link-external-16:](https://cmake.org/cmake/help/latest/manual/cmake-presets.7.html#workflow-preset){:target="_blank"} in the **CMake** documentation.

## Prerequisites
Make sure you execute **all** steps on this page in a terminal in the **root directory** of the [Unicado Package :octicons-link-external-16:](https://git.rwth-aachen.de/unicado/unicado-package){:target="_blank"} repository.

### Enable Parallel Builds (optional)
Since most machines nowadays have multiple cores, you can enable parallel builds to speed up the build process.
In fact, the release workflow will warn you if you don't. :wink:

As the release workflow invokes multiple different CMake modules, you have to enable the parallel build by setting an **environment variable** called [`CMAKE_BUILD_PARALLEL_LEVEL`](https://cmake.org/cmake/help/latest/envvar/CMAKE_BUILD_PARALLEL_LEVEL.html){:target="_blank"}:

=== "Windows"

    ```{.sh .copy}
    set CMAKE_BUILD_PARALLEL_LEVEL=<number_of_cores>
    ```

=== "Linux"

    ```{.sh .copy}
    export CMAKE_BUILD_PARALLEL_LEVEL=<number_of_cores>
    ```

**Do not insert any spaces around the `=` sign!**

!!! note
    The `<number_of_cores>` should be the number of cores your machine has.

## Build the Installer
The installer with all its needed components can be built by executing the following command:

=== "Windows"

    ```sh
    cmake --workflow --preset x64-windows-release
    ```

=== "Linux"

    ```sh
    cmake --workflow --preset x64-linux-release
    ```

This should also work out of the box with a freshly cloned version of the **Unicado Package** repository.

!!! note
    There is **no** *Debug* configuration for the installer package. The installer package has to always be built in **Release** mode!